{-# LANGUAGE OverloadedStrings #-}

import Data.GI.CodeGen.CabalHooks (setupBinding, TaggedOverride(..))



main :: IO ()
main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
  where name = "cairo"
        version = "1.0"
        overridesFile = Just "cairo.overrides"
        verbose = False
        outputDir = Nothing
        inheritedOverrides = []
